#
# spec file for package libmtp
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libmtp
Url:            http://sf.net/projects/libmtp
BuildRequires:  doxygen
BuildRequires:  libgcrypt-devel
BuildRequires:  libusb-1_0-devel
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(udev)
Summary:        Commandline utilities for access to MTP Players
License:        LGPL-2.1+
Group:          Productivity/Multimedia/Sound/Players
Version:        1.1.15
Release:        lp150.1.1
%define sonum   9
Source0:        http://downloads.sourceforge.net/project/%{name}/%{name}/%{version}/%{name}-%{version}.tar.gz
Source1:        http://downloads.sourceforge.net/project/%{name}/%{name}/%{version}/%{name}-%{version}.tar.gz.asc
Source2:        %name.keyring
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{!?_udevrulesdir: %global _udevrulesdir %(pkg-config --variable=udevdir udev)/rules.d }
%{!?_udevdir: %global _udevdir %(pkg-config --variable=udevdir udev) }

%description
This package contains binaries and documentation that allow access to
USB based media players based on the MTP (Media Transfer Protocol)
authored by Microsoft.

Common devices using this technology are Creative Zen, iRiver, Samsung
and others.

%package     -n %{name}-udev
Summary:        Udev rules for accessing MTP devices
Group:          Hardware/Mobile
Requires:       udev

%description -n %{name}-udev
This package contains the udev rules that allow access to USB based media
players based on the MTP (Media Transfer Protocol) authored by
Microsoft.

%package    -n %{name}%{sonum}
Summary:        Library for accessing MTP Players
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name}-udev >= %{version}

%description -n %{name}%{sonum}
This package contains the libraries that allow access to USB based media
players based on the MTP (Media Transfer Protocol) authored by
Microsoft.

Common devices using this technology are Creative Zen, iRiver, Samsung
and others.

%package -n mtp-tools
Summary:        Commandline utilities for access to MTP Players
Group:          Productivity/Multimedia/Sound/Players

%description -n mtp-tools
This package contains binaries that allow command line access to USB
based media players based on the MTP (Media Transfer Protocol) authored
by Microsoft. For graphical user interfaces use Amarok or Banshee.

%package devel
Summary:        Development files for access to MTP Player library
Group:          Development/Libraries/Other
Requires:       %{name}%{sonum} = %{version}

%description devel
This package contains the development headers for the libmtp library
that allows access to USB based media players based on the MTP (Media
Transfer Protocol) authored by Microsoft.

%prep
%setup -q

%build
echo 'HTML_TIMESTAMP=NO' >> doc/Doxyfile.in
%configure --with-udev=%{_udevdir} --disable-static --enable-doxygen
make %{?_smp_mflags}

%install
make install DESTDIR=$RPM_BUILD_ROOT
#install -d $RPM_BUILD_ROOT/usr/share/hal/fdi/information/20thirdparty/
#install -c -m 644 libmtp.fdi $RPM_BUILD_ROOT/usr/share/hal/fdi/information/20thirdparty/10-usb-music-players-libmtp.fdi
rm -rf %{buildroot}/usr/share/doc/libmtp*
rm -rf %{buildroot}/%{_libdir}/*.la

%post -n   %{name}%{sonum} -p /sbin/ldconfig
%postun -n %{name}%{sonum} -p /sbin/ldconfig

%files -n mtp-tools
%defattr(-, root, root)
%{_prefix}/bin/*

%files -n %{name}%{sonum}
%defattr(-, root, root)
%doc COPYING README ChangeLog AUTHORS
%{_libdir}/lib*.so.*
#%dir /usr/share/hal
#dir /usr/share/hal/fdi
#dir /usr/share/hal/fdi/information
#dir /usr/share/hal/fdi/information/20thirdparty/
#usr/share/hal/fdi/information/20thirdparty/10-usb-music-players-libmtp.fdi

%files -n %{name}-udev
%defattr(-, root, root)
%{_udevdir}
%{_udevrulesdir}

%files devel
%defattr(-, root, root)
%doc doc/html TODO
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/libmtp.pc
%{_prefix}/include/libmtp.h

%changelog
* Sat Mar 24 2018 meissner@suse.com
- updated to 1.1.15 release
  - lots of new USB ids
  - copy and move object implemented
  - 64bit file bugfixes
  - bugfixes
* Mon Oct  2 2017 meissner@suse.com
- updated to 1.1.14 release
  - lots of new USB ids
  - 64bit file bugfixes
  - bugfixes
* Sun Apr  2 2017 meissner@suse.com
- updated to 1.1.13 release (bsc#1033830)
  - lots of new USB id updates
  - getpartialobject64 fixed for non x86_64
  - some too strict bugflags removed for Galaxy S and Motorola G2
* Fri Aug 12 2016 meissner@suse.com
- updated to 1.1.12 release
  - lots of new USB id updates
  - async event function
* Wed Feb 10 2016 meissner@suse.com
- updated to 1.1.11 release
  - lots of new USB id updates
  - small usb 3 bugfix
- libmtp.keyring: temporary add my older key, as I mistakenly
  used that to sign the tarball
* Mon Oct 26 2015 dmitry_r@opensuse.org
- Split udev rules to separate package
* Sun Oct  4 2015 meissner@suse.com
- updated to 1.1.10 release
  - lots of new ids
  - various bugfixes
* Sun Jun 21 2015 crrodriguez@opensuse.org
- remove Requires on libusb-devel from libmtp-devel, the correct
  dependency is libusb1 already included by the pkgconfig
  generator.
* Thu Apr 30 2015 olaf@aepfle.de
- Package whole udev related dirs to avoid build failures
* Mon Apr 13 2015 meissner@suse.com
- updated to 1.1.9 release
  - lots and lots of new ids
  - bugfixes
- mtp_DroidTurbo.patch,include-config-h.patch: upstream
* Sat Mar 21 2015 meissner@suse.com
- update to 1.1.8
  - several new ids.
* Sat Jan 31 2015 rjschwei@suse.com
- Add device data for Droid Turbo
  add: mtp_DroidTurbo.patch
* Thu Sep 25 2014 schwab@suse.de
- include-config-h.patch: always include "config.h" first
* Tue Aug 26 2014 meissner@suse.com
- updated to 1.1.7
  - Soname libmtp.so.9.2.0 - binary compatible, new interfaces
    have been added.
  - Compilation fixes for older GCC and non-GCC compilers.
  - Finalize >4GB file transfer changes so this works now.
  - A new API to check for device capabilities has been added.
  - Sync in latest upstream ptp2 changes.
  - Support for USB 3.0! (A patch adding async buffering was
    reverted after deemed instable by Debian.)
  - Some migration toward the new API in the examples.
  - Use parent storage if available as default storage media.
  - Force reset on close for Android devices.
  - Handle integrated USB hubs in mtp-probe.
  - Devices, devices, devices...
- mtpz-use-LIBMTP_ERROR-instead-of-LIBMTP_INFO.patch: is upstream
- music-players.h: use up to date 1.1.7 version again.
* Tue May 27 2014 crrodriguez@opensuse.org
- Tell doxygen to stop producing files with timestamps.
- define udev macros only if not already there.
* Mon Dec  9 2013 meissner@suse.com
- music-players.h: Updated to the device database of the current GIT level
  to support more MTP devices (bnc#854328)
* Fri Sep 27 2013 rmilasan@suse.com
- Use LIBMTP_ERROR instead of LIBMTP_INFO function in mtpz_loaddata
  (mtpz.c) to dont get junk in the udev rule when generating the rule.
  add: mtpz-use-LIBMTP_ERROR-instead-of-LIBMTP_INFO.patch
* Fri Mar 15 2013 meissner@suse.com
- updated to 1.1.6
  - Soname libmtp.so.9.1.0 - binary compatible, new interfaces
    have been added.
  - Devices, devices, devices... I think I had a hundred (no kidding)
    reports for the Nexus 4. It seems hackers just love this device
    and cannot wait for me to spin a new libmtp.
  - More careful autoprobing code for Linux, running around in
    sysfs to try to avoid opening non-MTP devices. The libusb devs
    do not uniformly like this idea but what shall I do? People
    still want their devices to autodetect. Any hints welcome,
    any patches will be reviewed.
  - Interface extenstions from Philip Langdale to support the
    Android in-place read/write extensions. This will be used by
    GVFS for editing files etc, it is actually very useful when
    treating the MTP device as a "real" filesystem. It only works
    on Android devices with Google's MTP stack, but hey, that is
    a fair share of the MTP devices used today.
  - Several fixes and memory leaks fixed by Lei Zhang courtesy if
    the Chromebook project, thanks Google!
  - Windows Phone 8 should work out of the box.
- remove upstream libmtp_motoRazr.patch
* Fri Feb  8 2013 rschweikert@suse.com
- add support for Motorola Droid Razr M (XT 907)
* Sun Nov  4 2012 crrodriguez@opensuse.org
- mtp-probe no longer working in factory, wrong udev dir.
* Sat Sep 22 2012 toddrme2178@gmail.com
- updated to 1.1.5
  - Soname libmtp.so.9.0.5 - binary compatible
  - Stop forcing altinterface 0! That bug has been around like
    forever and libgphoto2 never did this. It screws up some
    Samsung devices and is the prime reason for releasing this
    update so soon after 1.1.4 as I know a lot of people out there
    have Samsung devices!
  - Integrated Sajid Anwars hard long-term work on MTPZ. There are
    no secret keys or certificates inside libmtp, if you need these
    to talk to your MTPZ device (Zune models, Windows Phones) you
    need to get a file of secrets from some other place, preferably
    Microsoft.
  - Expose getthumbnail method and the Add Storage events as needed
    for a GNOME VFS project by Philip Langdale.
  - Rearrange and try to understand some SONY device modes again
    and again.
  - A udev script fix from Alessio Treglia to avoid poking around
    on Canon EOS 3D.
  - Devices, devices, devices...
- Add libgrypt buildrequires for MTPZ support
* Sun Aug 19 2012 meissner@suse.com
- updated to 1.1.4
  - various bugfixes, especially in Samsung *
  - lots of new ids
* Tue Apr  3 2012 meissner@suse.de
- updated to 1.1.3
  - Soname libmtp.so.9.0.3 - binary compatible.
  - Probably nailed the bugs in the Samsung Galaxy Tab S2 family
    of devices. Ignacio Martinez helped us fixing this!
  - Build fixes by Alessio Treglia and others.
  - A horde of new devices in the database.
* Tue Jan 31 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
* Fri Jan 13 2012 meissner@suse.de
- updated to 1.1.2
  * device updates
  * ported to use libusb 1.0
  * Autodetect "sony.net" devices
* Thu Dec 29 2011 jengelh@medozas.de
- Remove redundant tags/sections (authors list, already in package
  as a file); put %%description after %%package
- Parallel build with %%_smp_mflags
* Thu Dec 29 2011 adrian@suse.de
- add support for Galaxy Nexus
* Wed Dec 21 2011 adrian@suse.de
- updated to 1.1.1
  * device updates
* Mon Sep 19 2011 meissner@suse.de
- updated to 1.1.0
  * lots of new devices
  * IAD (0xfe class) device detection
- drop HAL FDI snippets
- libmtp8 -> libmtp9
* Fri Jun 10 2011 andrea.turrini@gmail.com
- fixed typos in descriptions of libmtp.spec
* Tue Feb 15 2011 meissner@suse.de
- updated to 1.0.6
  * even less aggressive mtp probing (not detecting nearly all
    devices as MTP) bnc#668986
  * some more USB ids
* Tue Jan 25 2011 meissner@suse.de
- do not greedily match all PTP cameras in the udev rules.
* Mon Jan 10 2011 meissner@suse.de
- updated to 1.0.4 incremental release
  * new ids
  * bugfixes
  * new udev rules for new udev
* Sun May 23 2010 meissner@novell.com
- updated to 1.0.3 incremental release
  * some new ids
  * some smaller bugfixes
- buildrequre pkg-config
* Wed Apr 28 2010 meissner@suse.de
- updated to intermediate snapshot
  * Samsung fixes and new ids
  * various small bugfixes
* Mon Feb  1 2010 meissner@suse.de
- updated to 1.0.2 bugfix release
  * new ids: Samsung, Archos, Blackberry, ...
  * bugfixes
* Wed Sep 16 2009 meissner@suse.de
- updated to 1.0.1 bugfix release
  * last patches included
  * some more bug flags for devices
* Sat Sep  5 2009 meissner@suse.de
- bugfixes to "fast metadata loading" method
* Tue Aug  4 2009 meissner@suse.de
- upgraded to 1.0.0 release
  * More USB ids
  * libmtp.so.8.3.0 library interface
  * New functions:
    LIBMTP_Get_File_To_Handler
    LIBMTP_Send_File_From_Handler
    LIBMTP_Get_Track_To_Handler
    LIBMTP_Send_Track_From_Handler
    functions to get/send files/tracks from/to handler functions.
    External handling of individual properties:
    LIBMTP_Is_Property_Supported to check if a certain property is
    supported on a certain device.
    LIBMTP_Get_Allowed_Property_Values to get alowed range/enum of a
    property value.
    LIBMTP_Get_Representative_Sample_Format will now get the size
    parameter to allow us to determine the maximum size for a
    representative sample.
  * Added modificationdate to file and track structs.
  * Added LIBMTP_FILETYPE_ALBUM and LIBMTP_FILETYPE_PLAYLIST filetypes.
  * Numerous Windows portability fixes.
  * Marcus Meissner rewrote the PTP object handling and metadata caching
    functions from libgphoto2 and fixed up the ugly largefile handling.
  * Various minor bug fixes.
* Tue Mar 17 2009 meissner@suse.de
- upgraded to 0.3.7
  * compatible library interface libmtp.8.2.2
  * stores albums and playlists in the default
    music folder if no default folder for albums resp.
    playlists has been detected.
  * an error report from RedHat BZ
    http://bugzilla.redhat.com/show_bug.cgi?id=485627
    led to strange code for detecting anonymous OGG files
    being rewritten to handle NULL filenames and filenames
    that do not exceed 4 chars.
  * patch from Marcus to fix an issue
    with retransmit originally reported by Florent Pillet.
  * discovered a new device that cannot even
    read out battery level but still claims to be able to.
- upgraded to 0.3.6
  * Compatible API libmtp.so.8.2.1
  * Several bug fixes to the examples
  * Improved Windows and *BSD support
  * Proper device flags to handle Toshiba players (hopefully)
  * New devices and flag settings
  * Nothing new from a programmers point of view
- upgraded to 0.3.5
  * Bumped soname to libmtp.so.8.2.0
  - Only interface change:
  * Change metadata const*const to *const to allow playlist_id to be
    modified by LIBMTP_Update_Playlist. Shouldn't affect any code out
    there really.
  - New features and bugfixes:
  * Allow for playlists with zero tracks on them (also in update).
  * Get folders to a flat list and we get O(n) searching instead of
    the previous O(n^2) algorithm! The rest is janitorial changes.
* Mon Dec 15 2008 meissner@suse.de
- detach the Cowon iAudio 7 from usb-storage on start to make it work
  bnc#457931
* Fri Nov  7 2008 meissner@suse.de
- upgraded to 0.3.4
  * Check propdesc before setting props in create_new_abstract_list() (Richard)
  * Fix several bugs in Ogg filetype support (Alvin)
  * New flag for broken handling of PTP_OPC_DateModified, tag all
  SanDisk devices with this flag. Bug appeared in them. (Linus)
  * Sync in upstream updates to PTP baseline (Linus)
  * Detect and warn on broken OPLs (Richard)
  * Fix the association type problem on LIBMTP_Create_Folder(). This
  caused folders not to work properly on some devices!! (Linus)
* Wed Oct 22 2008 mrueckert@suse.de
- fix debug_packages_requires define
* Fri Sep 26 2008 meissner@suse.de
- upgraded to 0.3.3
  - lots of new ids
  - protocol bugfixes for Samsung and Creative devices
  - bugfixes
* Wed Aug 27 2008 meissner@suse.de
- let debuginfo require libmtp8
- disable static libs and .la files
* Tue Aug 26 2008 meissner@suse.de
- upgraded to 0.3.1
  - lots of new ids
  - sansa player handling better now
  - special playlist support for a subkind of devices
- commandline tools now live in mtp-tools, libmtp is empty.
* Tue Jun 24 2008 meissner@suse.de
- upgraded to 0.3.0
  - new major version 8 due to API changes
  - new devices
  - lots of bugfixes
- libmtp7 renamed to libmtp8
- doxygen added as buildrequires
* Tue Mar 11 2008 meissner@suse.de
- upgraded to 0.2.6.1
  - disabled debug
- info.bus -> info.subsystem in FDI file
* Mon Mar  3 2008 meissner@suse.de
- upgraded to 0.2.6
  - some new devices
  - bugfixes
  - remove LIBMTP_Set_Object_Parent function -> new major
* Wed Jan  9 2008 meissner@suse.de
- upgraded to 0.2.5
  - several new devices
  - code cleanups and bugfixes
* Mon Nov 26 2007 meissner@suse.de
- upgraded to 0.2.4
  - various bug fixes and new fixes
  - header-repairing for Zen devices
* Sun Oct 28 2007 meissner@suse.de
- --program-prefix=mtp- is needed.
* Fri Oct 26 2007 meissner@suse.de
- upgraded to 0.2.3
  - new devices added
  - varous bugfixes, speed ups
  - bumped so from 6 to 7
- split off libmtp7 package
* Mon Oct  8 2007 meissner@suse.de
- upgraded to 0.2.2
  - bugfixes, new devices, faster metadata read
* Fri Aug 10 2007 meissner@suse.de
- upgraded to 0.2.1 release
  - fixed for LFS support
* Sat Aug  4 2007 meissner@suse.de
- upgraded to 0.2.0 release
  - more USB ids
  - 64bit handling
* Thu Jul 26 2007 meissner@suse.de
- uprgaded to current CVS state
  - caching of fs and metadata
  - new devices
  - ptp reset binary
  - bugfixes
* Mon Jun  4 2007 stbinner@suse.de
- fix build requires for older distributions
* Wed May 16 2007 olh@suse.de
- Buildrequires libusb -> libusb-devel
  Remove unneded Requires libusb
  - devel package requires libusb-devel
* Tue Mar 27 2007 meissner@suse.de
- upstream 0.1.5
  - uses SetObjPropList for most devices
  - usb lowlevel communication fixes for
  stubborn devices
  - some new ids
* Wed Mar  7 2007 meissner@suse.de
- upstream 0.1.4
  - lots of bugfixes
  - multiple device handling
* Thu Feb  8 2007 dmueller@suse.de
- split into -devel subpackage
* Wed Jan 17 2007 meissner@suse.de
- upstream 0.1.3
  - bugfixes.
* Wed Jan 10 2007 meissner@suse.de
- use %%run_ldconfig in post/postun. (from rpmlint)
* Mon Jan  8 2007 meissner@suse.de
- Upgraded to 0.1.2:
  - new devices
  - lots of bugfixes, rewritten lowlevel
  communications layer.
* Sat Dec  2 2006 meissner@suse.de
- Upgraded to 0.1.0:
  - new devices
  - metadata, tracks, vcf handling
  - enhanced tools
  - HAL snippet
* Thu Sep 21 2006 meissner@suse.de
- Upgraded to 0.0.19:
  - formatting of devices added
  - lots of fixes
* Mon Aug 28 2006 meissner@suse.de
- Upgraded to 0.0.16
  - better handling of non-ascii filenames
  - handling of large files
* Wed Aug 23 2006 meissner@suse.de
- libmtp 0.0.13
  - Library to access MTP devices.
  - Small sample tools for accessing.
